/**
 * Script JavaScript pour l'arbre de décision Zingtree
 */

(function($) {
    'use strict';

    // Variables globales
    let decisionTree = null;
    let currentNodeId = '1'; // Commencer par le nœud racine
    let history = []; // Historique des nœuds visités
    let maxDepth = 10; // Profondeur maximale estimée de l'arbre
    
    /**
     * Initialisation au chargement du document
     */
    $(document).ready(function() {
        // Charger l'arbre de décision
        loadDecisionTree();
        
        // Ajouter les écouteurs d'événements pour les boutons de navigation
        $('#back-button').on('click', goBack);
        $('#restart-button').on('click', restart);
    });
    
    /**
     * Fonction pour charger les données de l'arbre de décision
     */
    function loadDecisionTree() {
        // Afficher l'animation de chargement
        $('#node-content').addClass('loading');
        
        // Charger les données depuis l'URL fournie par WordPress
        $.ajax({
            url: zingtreeData.treeDataUrl,
            type: 'GET',
            dataType: 'json',
            headers: {
                'X-WP-Nonce': zingtreeData.nonce
            },
            success: function(data) {
                decisionTree = data;
                // Afficher le nœud initial
                displayNode(currentNodeId);
            },
            error: function(xhr, status, error) {
                console.error('Erreur lors du chargement de l\'arbre de décision:', error);
                $('#node-content').removeClass('loading').html(
                    '<p>Une erreur est survenue lors du chargement de l\'outil. Veuillez réessayer plus tard.</p>'
                );
            }
        });
    }
    
    /**
     * Fonction pour afficher un nœud spécifique
     */
    function displayNode(nodeId) {
        const node = decisionTree.nodes[nodeId];
        if (!node) {
            console.error(`Nœud ${nodeId} non trouvé`);
            return;
        }
        
        // Mettre à jour l'historique si c'est un nouveau nœud
        if (currentNodeId !== nodeId && !history.includes(currentNodeId)) {
            history.push(currentNodeId);
        }
        
        // Mettre à jour le nœud actuel
        currentNodeId = nodeId;
        
        // Mettre à jour l'en-tête
        $('#node-header').text(node.page_title || "Outil pour les responsables énergies");
        
        // Mettre à jour le contenu
        $('#node-content').removeClass('loading').html(node.content || "");
        
        // Mettre à jour les boutons
        $('#node-buttons').empty();
        
        if (node.buttons && node.buttons.length > 0) {
            node.buttons.forEach(function(button) {
                const buttonElement = $('<button></button>')
                    .addClass('button')
                    .text(button.button_text)
                    .on('click', function() {
                        displayNode(button.button_link);
                    });
                $('#node-buttons').append(buttonElement);
            });
        }
        
        // Mettre à jour l'état du bouton Précédent
        $('#back-button').prop('disabled', history.length === 0);
        
        // Mettre à jour la barre de progression
        updateProgressBar();
        
        // Faire défiler vers le haut
        $('html, body').animate({
            scrollTop: $('#zingtree-container').offset().top - 50
        }, 300);
    }
    
    /**
     * Fonction pour revenir au nœud précédent
     */
    function goBack() {
        if (history.length > 0) {
            const previousNodeId = history.pop();
            displayNode(previousNodeId);
        }
    }
    
    /**
     * Fonction pour recommencer
     */
    function restart() {
        // Demander confirmation
        if (history.length > 0 && !confirm('Êtes-vous sûr de vouloir recommencer ? Votre progression sera perdue.')) {
            return;
        }
        
        history = [];
        currentNodeId = '1';
        displayNode(currentNodeId);
    }
    
    /**
     * Fonction pour mettre à jour la barre de progression
     */
    function updateProgressBar() {
        // Calculer la progression basée sur la profondeur actuelle dans l'arbre
        const depth = history.length;
        const progress = Math.min(100, (depth / maxDepth) * 100);
        $('#progress-bar').css('width', progress + '%');
    }
    
    /**
     * Fonction pour gérer les erreurs
     */
    function handleError(message) {
        console.error(message);
        $('#node-content').removeClass('loading').html(
            '<p>Une erreur est survenue: ' + message + '</p>'
        );
    }
    
    /**
     * Fonction pour sanitiser le contenu HTML
     * Note: Dans une implémentation réelle, il faudrait utiliser une bibliothèque
     * comme DOMPurify pour une sanitisation plus robuste
     */
    function sanitizeHTML(html) {
        const temp = document.createElement('div');
        temp.textContent = html;
        return temp.innerHTML;
    }
    
    /**
     * Exposer certaines fonctions pour les tests
     */
    window.ZingtreeDecisionTree = {
        displayNode: displayNode,
        goBack: goBack,
        restart: restart
    };
    
})(jQuery);
